=======
drosSRA
=======


.. image:: https://img.shields.io/pypi/v/drosSRA.svg
        :target: https://pypi.python.org/pypi/drosSRA

.. image:: https://img.shields.io/travis/isabelleberger/drosSRA.svg
        :target: https://travis-ci.org/isabelleberger/drosSRA

.. image:: https://readthedocs.org/projects/drosSRA/badge/?version=latest
        :target: https://drosSRA.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




drosSRA builds a url for visualization of tracks based on user specified parameters (i.e. sex, tissue, cell type)


* Free software: MIT license
* Documentation: https://drosSRA.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
